import { minioClient } from '@/app.ts';
import { bucketName } from '@/modules/minio.ts';

type MinioListOpt = {
  prefix: string;
  recursive?: boolean;
};
export type MinioFile = {
  name: string;
  size: number;
  lastModified: Date;
  etag: string;
};
export type MinioDirectory = {
  prefix: string;
  size: number;
};
export type MinioList = (MinioFile | MinioDirectory)[];
export const getMinioList = async (opts: MinioListOpt): Promise<MinioList> => {
  const prefix = opts.prefix;
  const recursive = opts.recursive ?? false;
  return await new Promise((resolve, reject) => {
    let res: any[] = [];
    let hasError = false;
    minioClient
      .listObjectsV2(bucketName, prefix, recursive)
      .on('data', (data) => {
        res.push(data);
      })
      .on('error', (err) => {
        console.error('minio error', opts.prefix, err);
        hasError = true;
      })
      .on('end', () => {
        if (hasError) {
          reject();
          return;
        } else {
          resolve(res);
        }
      });
  });
};
export const getFileStat = async (prefix: string): Promise<any> => {
  try {
    const obj = await minioClient.statObject(bucketName, prefix);
    return obj;
  } catch (e) {
    if (e.code === 'NotFound') {
      return null;
    }
    console.error('get File Stat Error not handle', e);
    return null;
  }
};
